import { DynamoAttributeValue } from "@aws-cdk/aws-stepfunctions-tasks";
import { DynamoAttributeName } from "./attribute-name";
import { Placeholder } from "./placeholder";
declare type AttributeValues = {
    [key: string]: DynamoAttributeValue;
};
declare type AttributeNames = {
    [key: string]: DynamoAttributeName;
};
export interface PartialDynamoAPICallProps {
    /**
     * Built update expression that contains calculated placeholders.
     */
    readonly updateExpression?: string;
    /**
     * Built condition expression that contains calculated placeholders.
     */
    readonly conditionExpression?: string;
    /**
     * attribute values that used to substitute expression's placeholders by DynamoDB.
     */
    readonly expressionAttributeValues: AttributeValues;
    /**
     * attribute names that used to substitute expression's placeholders by DynamoDB.
     */
    readonly expressionAttributeNames?: AttributeNames;
}
export interface ExpressionAggregate {
    /**
     * Built expression that contains calculated placeholders.
     */
    readonly expression: string;
    /**
     * attribute values that used to substitute expression's placeholders by DynamoDB.
     */
    readonly expressionAttributeValues: AttributeValues;
    /**
     * attribute names that used to substitute expression's placeholders by DynamoDB.
     */
    readonly expressionAttributeNames?: AttributeNames;
}
/**
 * An ExpressionBuilder instance builds the expression using calculated placeholders by referred attribute names and values.
 *
 * Each instance must correspond to the DynamoDB requests that using the expression.
 * If instances are used across different requests, the names and values that substitutes the placeholders may misplaced.
 */
export declare class ExpressionBuilder {
    private readonly valuesRefCounter;
    private readonly namesRefCounter;
    private updateExpressionFragment?;
    private conditionExpressionFragment?;
    constructor();
    /**
     * Returns merged expression attributes from added update expression and condition expression.
     */
    aggregate(): PartialDynamoAPICallProps;
    /**
     * Add update expression.
     */
    update(literals: TemplateStringsArray, ...placeholders: Placeholder[]): ExpressionAggregate;
    /**
     * Add condition expression.
     */
    condition(literals: TemplateStringsArray, ...placeholders: Placeholder[]): ExpressionAggregate;
    /**
     * Builds an expression and expression attribute values from template string.
     *
     * @deprecated See `update`, `condition` and `aggregate`
     */
    expr(literals: TemplateStringsArray, ...placeholers: Placeholder[]): ExpressionAggregate;
    /**
     *
     */
    private build;
}
export {};
